package com.jiashi;

import com.google.gson.Gson;
import com.jiashi.service.FormField;
import okhttp3.*;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.TimeUnit;

public class FileUploader {


    public static CommonResult uploadFilesWithParams(List<File> files, String uploadUrl, List<FormField> params) throws IOException {
        OkHttpClient client = new OkHttpClient.Builder()
                .connectTimeout(600, TimeUnit.SECONDS)
                .readTimeout(600, TimeUnit.SECONDS)
                .writeTimeout(600, TimeUnit.SECONDS)
                .build();
        MultipartBody.Builder builder = new MultipartBody.Builder();
        for (File file : files) {
            RequestBody body = RequestBody.create(MediaType.parse("multipart/form-data"), file);
//                RequestBody body = RequestBody.create(MediaType.parse("image/jpeg"), file);
            builder.addFormDataPart("files", file.getName(), body);
        }
        for(FormField formField:params){
            builder.addFormDataPart(formField.getKey(), formField.getValue());
        }
        // 下行是上传的json的对象，其中上面的fileName和下行的fromData需和后台接口名字一致
        RequestBody requestBody = builder.setType(MultipartBody.FORM).build();
        final Request request = new Request.Builder()
                .url(uploadUrl)
                .post(requestBody)
                .build();

        Response response = client.newCall(request).execute();
        String responseBody = response.body().string();
        CommonResult commonResult = new Gson().fromJson(responseBody, CommonResult.class);
        return commonResult;

    }

    public static void deleteFolder(File folder) {
        if (folder.isDirectory()) {
            File[] files = folder.listFiles();
            if (files != null) {
                for (File file : files) {
                    deleteFolder(file);
                }
            }
        }
        folder.delete();
    }

    public static void main(String[] args) throws IOException {
        List<File> files = new ArrayList<>();
        files.add(new File("C:\\jiahsi-saomiao\\413425_刘燊杨_20221009_004624\\16763947060057863381.jpg"));
//        files.add(new File("C:\\jiahsi-saomiao\\413425_刘燊杨_20221009_004624\\16763947060420811242.jpg"));


        // 额外的表单字段参数
        List<FormField> params = new ArrayList<>();
        params.add(new FormField("uploadFileParams", "[ {\"inpatientNo\":\"35131\", \"disDate\":\"2020-07-30 00:00:00.000\", \"fileTitle\":\"16763947060057863381.jpg\", \"uploadFileName\":\"16763947060057863381.jpg\", \"assortId\":\"078F7675CB0048EDBE586D59831C57B0\" ,\n" +
                "\"patientId\":\"12312312\",\n" +
                "\"name\":\"长三\",\n" +
                "\"admissDate\":\"2022-02-01\",\n" +
                "\"sex\":\"男女\"\n" +
                "}\n" +
                "]"));

        // 上传URL
        String uploadUrl = "http://192.168.16.116:8711/api/downplatform/fileUploadJpg";

        // 执行批量上传
        uploadFilesWithParams(files, uploadUrl, params);
    }


}
